@@ -111,20 +111,6 @@ void uobject_root_init(sObject* self)
     ASSERT(TYPE(self) == T_UOBJECT);
 
     uobject_put(self, "unset", NFUN_NEW_GC(cmd_unset, NULL, TRUE));
-    sObject* readline = UOBJECT_NEW_GC(8, self, "rl", TRUE);
-    uobject_init(readline);
-    uobject_put(self, "rl", readline);
-
-    uobject_put(readline, "file_name_completion_null_generator", NFUN_NEW_GC(cmd_readline_file_name_completion_null_generator, NULL, TRUE));
-    uobject_put(readline, "forced_update_display", NFUN_NEW_GC(cmd_readline_forced_update_display, NULL, TRUE));
-    uobject_put(readline, "insert_text", NFUN_NEW_GC(cmd_readline_insert_text, NULL, TRUE));
-    uobject_put(readline, "delete_text", NFUN_NEW_GC(cmd_readline_delete_text, NULL, TRUE));
-    uobject_put(readline, "clear_screen", NFUN_NEW_GC(cmd_readline_clear_screen, NULL, TRUE));
-    uobject_put(readline, "point_move", NFUN_NEW_GC(cmd_readline_point_move, NULL, TRUE));
-    uobject_put(readline, "read_history", NFUN_NEW_GC(cmd_readline_read_history, NULL, TRUE));
-    uobject_put(readline, "write_history", NFUN_NEW_GC(cmd_readline_write_history, NULL, TRUE));
-    uobject_put(readline, "replace_line", NFUN_NEW_GC(cmd_readline_replace_line, NULL, TRUE));
-    uobject_put(readline, "point", NFUN_NEW_GC(cmd_readline_point, NULL, TRUE));
     uobject_put(self, "completion", NFUN_NEW_GC(cmd_completion, NULL, TRUE));
     uobject_put(self, "p", NFUN_NEW_GC(cmd_p, NULL, TRUE));
     uobject_put(self, "jobs", NFUN_NEW_GC(cmd_jobs, NULL, TRUE));
@@ -281,6 +267,8 @@ void uobject_root_init(sObject* self)
     (void)nfun_put_option_with_argument(nfun, STRDUP("-option-with-argument"));
     uobject_put(self, "class", nfun);
 
+    readline_object_init(self);
+
     clear_matching_info_variable();
 }
 
